get files="wm.sav" /keep hh1 hh2 ln wm7 wm9 wage wmweight.
sort cases by hh1 hh2 ln.
save out="tmp.sav"
  /rename (ln=hl1).

get files="hl.sav".
select if (hl5 >= 10 and hl5 <= 54 and hl4 = 2).
recode hl5 (10 thru 14 = 0)  (15 thru 19 = 1) (20 thru 24 = 2) (25 thru 29 = 3) (30 thru 34 = 4) 
	(35 thru 39 = 5) (40 thru 44 = 6) (45 thru 49 = 7) (50 thru 54 = 8) into wage.
variable label wage "Age".
value label wage
  0 "10-14"
  1 "15-19"
  2 "20-24"
  3 "25-29"
  4 "30-34"
  5 "35-39"
  6 "40-44"
  7 "45-49"
  8 "50-54".

sort cases by hh1 hh2 hl1.
save out="tmp1.sav".

* merge files together.
match files
  /file = *
  /table = 'tmp.sav'
  /by  HH1 HH2 HL1.

compute t1549i = 0.
if (WM7 = 1) t1549i = 1.
compute t1054 = 1.
if (hl5 >= 15 and hl5 <= 49) t1549 = 1.

compute total = 1.
variable label total "Total".
value label total 1 "".
if (WM7 = 1) elig = 1.

aggregate outfile = 'tmp3.sav'
  /break   = wage
  /tt1054  = sum(t1054)
  /tt1549  = sum(t1549)
  /tt1549i = sum(t1549i)
  /telig  = sum(elig).

aggregate outfile = 'tmp4.sav'
  /break   = total
  /tt1054  = sum(t1054)
  /tt1549  = sum(t1549)
  /tt1549i = sum(t1549i)
  /telig  = sum(elig).

get file = 'tmp3.sav'.

add files
  /file = *
  /file = 'tmp4.sav'.

variable label tt1054 'Household population of women age 10-54'.
variable label tt1549i 'Interviewed women age 15-49'.

compute pelig = (tt1549i/tt1549)*100.
variable label pelig "Percentage of eligible women interviewed".

tables
  /format = zero
  /observation= tt1054 tt1549i pelig
  /table= wage + total by tt1054 + tt1549i + pelig 
  /statistics
    sum(tt1054 (f5.0) 'Number')
    spct(tt1054 (f5.1) 'Percent')
    sum(tt1549i (f5.0) 'Number')
    spct(tt1549i (f5.1) 'Percent')
    means(pelig (f5.1) ' ')
  /title
    "Table DQ.2: Age distribution of eligible and interviewed women"
                       "Household population of women age 10-54, interviewed women age 15-49, and percentage of " +
                       "eligible women who were interviewed (weighted) by five-year age group, Uzbekistan, 2006".

new file.
erase file 'tmp.sav'.
erase file 'tmp1.sav'.
erase file 'tmp3.sav'.
erase file 'tmp4.sav'.