*------------------------------------------------------------------------------------------------------------------------- VARIABLES FROM HOUSEHOLD.

get file = 'hh.sav'.
subgroup.
select if (HH9 = 1).
compute hhweight = hhweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*------------------------------------------------------------------------------------------------------------------------- Iodized salt consumption.

recode SI1 (7=0)  (1,2 = 0) (3 = 1) (else = sysmis) into iodized.
variable label iodized "Iodized salt consumption".

*------------------------------------------------------------------------------------------------------------------------- Calculate sampling errors.

CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=hhweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = iodized
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

*------------------------------------------------------------------------------------------------------------------------- Weight by household members.
compute hhweight = hhweight*hh11.
*------------------------------------------------------------------------------------------------------------------------- Use of improved drinking water sources.

compute improved = 0.
if (WS1 = 11 or  WS1 = 12 or WS1 = 13 or WS1 = 21 or WS1 = 31 or WS1 = 41 or WS1 = 51) improved = 1.
if ((WS2 = 11 or WS2 = 12 or WS2 = 13 or WS2 = 21 or WS2 = 31 or WS2 = 41 or WS2 = 51) and WS1 = 91) improved = 1. 
variable label improved "Use of improved drinking water sources".

*------------------------------------------------------------------------------------------------------------------------- Use of improved sanitation facilities.

recode WS7 (11,12,13,21,22,31 = 1) (else = 0) into sanitary.
variable label sanitary "Use of improved sanitation facilities".

*------------------------------------------------------------------------------------------------------------------------- Calculate sampling errors.

CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=hhweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = improved sanitary
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

*------------------------------------------------------------------------------------------------------------------------- VARIABLES FROM HOUSEHOLD LISTING.

get file = 'hl.sav'.
subgroup.
compute hhweight = hhweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*------------------------------------------------------------------------------------------------------------------------- Use of improved drinking water sources.

compute improved = 0.
if (WS1 = 11 or  WS1 = 12 or WS1 = 13 or WS1 = 21 or WS1 = 31 or WS1 = 41 or WS1 = 51) improved = 1.
if ((WS2 = 11 or WS2 = 12 or WS2 = 13 or WS2 = 21 or WS2 = 31 or WS2 = 41 or WS2 = 51) and WS1 = 91) improved = 1. 
variable label improved "Use of improved drinking water sources".

*------------------------------------------------------------------------------------------------------------------------- Use of improved sanitation facilities.

recode WS7 (11,12,13,21,22,31 = 1) (else = 0) into sanitary.
variable label sanitary "Use of improved sanitation facilities".

*------------------------------------------------------------------------------------------------------------------------- Net primary school attendance rate.
* select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your country.

do if (HL5 >= 7 and HL5 <= 11).
+ compute primary  = 0.
+ if (ED6A >= 1 and ED6A <= 3) primary =  1.
end if.
variable label primary "Net primary school attendance rate".

*------------------------------------------------------------------------------------------------------------------------- Net secondary school attendance rate.
* select children who are of secondary school age; this definition is
* country-specific and should be changed to reflect the situation in your country.

do if (HL5 >= 12 and HL5 <= 17).
+ compute second  = 0.
+ if (ED6A >= 2 and ED6A <= 4) second =  1.
end if.
variable label second "Net secondary school attendance rate".

*------------------------------------------------------------------------------------------------------------------------- Primary completion rate.
* select children who are of primary school graduation age; this definition is
* country-specific and should be changed to reflect the situation in your country.

* Primary school graduation age.
compute maxage = 11.
* Last primary grade.
compute higrade = 4.
do if (HL5 = maxage).
+ compute plgrade = 0.
+ if ((ED6A = 1 and ED6B >= higrade and ED6B < 8) or (ED6A >= 2 and ED6A < 8)) plgrade = 1.
* Exclude repeats.
+ if (ED8A = ED6A and ED8B  = ED6B) plgrade = 0.
end if.
variable label plgrade "Primary completion rate".

*------------------------------------------------------------------------------------------------------------------------- Child labour.

if (HL5 >= 5 and HL5 <= 14) working = 0.
recode CL4 CL9 (98,99,sysmis = 0) .
compute hours = CL4 + CL9.
if ((HL5 >= 5 and HL5 <= 11) and (CL3 = 1 or CL3 = 2 or CL8 = 1 or (CL7 >= 28 and CL7 <= 95))) working = 1.
if ((HL5 >= 12 and HL5 <= 14) and ((CL7 >= 28 and CL7 <= 95) or (hours >= 14 and hours <= 190))) working = 1.
variable label working "Child labour".

*------------------------------------------------------------------------------------------------------------------------- Orphans.

do if (HL5 <= 17).
+ compute orphan = 0.
+ if (HL9 = 2 or HL11 = 2) orphan = 1.
end if.
variable label orphan "Prevalence of orphans".

*------------------------------------------------------------------------------------------------------------------------- Calculate sampling errors.

CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=hhweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = primary second plgrade working orphan
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

*------------------------------------------------------------------------------------------------------------------------- VARIABLES FROM WOMEN.

get file = 'wm.sav'.
subgroup.
select if (WM7 = 1).
compute wmweight = wmweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*------------------------------------------------------------------------------------------------------------------------- Skilled attendant at delivery.

do if (CM12 = "Y" or CM12 = "O" or CM12 = "S").
+ compute skilled = 0.
+ if (MN7A = "A" or MN7B = "B" or MN7C = "C") skilled = 1.
end if.
variable label skilled "Skilled attendant at delivery".

*------------------------------------------------------------------------------------------------------------------------- Antenatal care.

do if (CM12 = "Y" or CM12 = "O" or CM12 = "S").
+ compute ancskill = 0.
+ if (MN2A = "A" or MN2B = "B" or MN2C = "C") ancskill = 1.
end if.
variable label ancskill "Antenatal care".

*------------------------------------------------------------------------------------------------------------------------- Contraceptive prevalence.

do if (mstatus = 1).
+ compute anymeth = 0.
+ if (CP2 = 1) anymeth = 1.
end if.
variable label anymeth "Contraceptive prevalence".

*------------------------------------------------------------------------------------------------------------------------- Adult literacy.

do if (WM9 >= 15 and WM9 <= 24).
+ compute literate  = 0.
+ if (WM14 = 3 or WM11 = 2 or WM11 = 3 or WM11 = 4) literate = 1.
end if.
variable label literate "Adult literacy".

*------------------------------------------------------------------------------------------------------------------------- Marriage before age 18.

do if (WM9 >= 20).
+ compute agem18 = 0.
+ if (agem < 18) agem18 = 1.
end if.
variable label agem18 "Marriage before age 18".


*------------------------------------------------------------------------------------------------------------------------- Comprehensive correct knowledge of HIV.

do if (WM9 <= 24).
+ compute compre = 0.
+ if ((HA2 = 1 and HA4 = 1) and (HA3 = 2 and HA5 = 2 and HA8 = 1)) compre = 1.
end if.
variable label compre "Comprehensive knowledge about HIV prevention among young people".

*------------------------------------------------------------------------------------------------------------------------- Condom use at last sex with non-marital partner.

do if ((WM9 >= 15 and WM9 <= 24) and (SB1 <> 0 and SB2U >= 1 and SB2U <= 3) and ((SB4 >= 2 and SB4 <= 6) or (SB8 >= 2 and SB8 <= 6))).
+ compute condom = 0.
+ if ((SB4 >= 2 and SB4 <= 6 and SB3 = 1) or (SB4 = 1 and SB8 >= 2 and SB8 <= 6 and SB7 = 1)) condom = 1.
end if.
variable label condom "Condom use with non-regular partners".

*------------------------------------------------------------------------------------------------------------------------- Age at first sex before age 15.

do if (WM9 >= 15 and WM9 <= 19).
+ compute sex15 = 0.
+ if (SB1 <> 0 and SB1 < 15) sex15 = 1.
+ if (SB1 = 95 and agem >= 4 and agem < 15) sex15 = 1.
end if.
variable label sex15 "Age at first sex among young people".

*------------------------------------------------------------------------------------------------------------------------- Accepting attitudes towards people with HIV.

do if (HA1 = 1).
+ compute accept = 1.
+ if (HA13 = 2 or HA12 = 1 or HA10 = 2 or HA11 = 2) accept = 0.
end if.
variable label accept "Attitudes towards people with HIV/AIDS".

*------------------------------------------------------------------------------------------------------------------------- Women who have been tested for HIV.

compute tested = 0.
if (HA15 = 1 or MN5 = 1) tested = 1.
variable label tested "Women who have been tested for HIV".

*------------------------------------------------------------------------------------------------------------------------- Know mother to child transmission.

compute knowmtct = 0.
if (HA9A = 1 and HA9B = 1 and HA9C = 1) knowmtct = 1.
variable label knowmtct "Knowledge of mother-to-child transmission of HIV".

*------------------------------------------------------------------------------------------------------------------------- Calculate sampling errors.

CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=wmweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = skilled ancskill anymeth literate agem18 compre condom sex15 accept tested knowmtct
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.


*------------------------------------------------------------------------------------------------------------------------- VARIABLES FROM CHILDRENS DATA.

get file = 'ch.sav'.
subgroup.
select if (UF9 = 1).
compute chweight = chweight*1000000.
match files
  /file = *
  /table = 'pairs.sav'
  /by HH1.

*------------------------------------------------------------------------------------------------------------------------- Underweight Prevalence.

compute misshw = 0.
if (AN1 >= 99.0 or AN2 >= 999.0) misshw = 100.
variable label misshw "Missing height or weight".

do if (misshw = 0).
+ recode WAZ (-2.00 thru hi = 0) (else = 1) into wa2.
else.
+ compute wa2 = 9.
end if.
if (flag ne 0)  wa2 = 9.

variable label wa2 "Underweight prevalence".
missing values wa2 (9).

*------------------------------------------------------------------------------------------------------------------------- Immunizations.

include file = "04 - chrecvac.sps".

do if (cage >= 15 and cage <= 26).
+ recode bcg (1,2 = 1) (3 = 0) into bcg_r.
+ recode dpt3 (1,2 = 1) (3 = 0) into dpt3_r.
+ recode polio3 (1,2 = 1) (3 = 0) into polio3_r.
+ recode measles (1,2 = 1) (3 = 0) into meales_r.
+ recode allvacc (1,2 = 1) (3 = 0) into all_r.
end if.
variable label bcg_r "Tuberculosis immunization coverage".
variable label dpt3_r "Immunization coverage for DPT".
variable label polio3_r "Polio immunization coverage".
variable label meales_r "Measles immunization coverage".
variable label all_r "Fully immunized children".

*------------------------------------------------------------------------------------------------------------------------- Antibiotic treatment of suspected pneumonia.
* ARI in the last 2 weeks.

compute ari  = 0.
if ((CA7 = 1 or CA7 = 3) and CA5 = 1 and CA6 = 1) ari = 1.
variable label ari "Acute respiratory infection in last two weeks".

do if (ari = 1).
+ recode CA11A ("A" = 1) (else = 0) into anti.
end if.
variable label anti "Antibiotic treatment of suspected pneumonia".

*------------------------------------------------------------------------------------------------------------------------- Received ORT or increased fluids, and continued feeding.
* Diarrhoea in last 2 weeks.

recode CA1 (1 = 1) (else = 0) into diarrhea.
variable label diarrhea "Diarrhoea in last two weeks".

do if (CA1 = 1).
+ recode CA3 (3 = 1) (else = 0) into drnkmore.
+ recode CA3 (1,2 = 1) (else = 0) into drnkless.
+ recode CA4 (3,4,5 = 1) (else = 0) into ateokay.
+ recode CA4 (1,2 = 1) (else = 0) into atebadly.
+ compute homemgmt = 0.
+ if (drnkmore = 1 and ateokay = 1) homemgmt = 1.
+ compute orifcf = 0.
+ if ((CA2A = 1 or CA2B = 1 or drnkmore = 1) and ateokay = 1) orifcf = 1.
+ compute dtotal = 1.
end if.

*do if (diarrhea = 1).
*+ compute orifcf = 0.
*+ if ((CA2A = 1 or CA2B = 1 or CA2C = 1 or CA3 = 3) and (CA4 = 3 or CA4 = 4 or CA4 = 5)) orifcf = 1.
*end if.
variable label orifcf "Received ORT or increased fluids and continued feeding".

*------------------------------------------------------------------------------------------------------------------------- Support for learning.

compute activity = 0.
if (BR8AM = "A" or BR8AF = "B" or BR8AO = "X") activity = activity + 1.
if (BR8BM = "A" or BR8BF = "B" or BR8BO = "X") activity = activity + 1.
if (BR8CM = "A" or BR8CF = "B" or BR8CO = "X") activity = activity + 1.
if (BR8DM = "A" or BR8DF = "B" or BR8DO = "X") activity = activity + 1.
if (BR8EM = "A" or BR8EF = "B" or BR8EO = "X") activity = activity + 1.
if (BR8FM = "A" or BR8FF = "B" or BR8FO = "X") activity = activity + 1.
variable label activity "Mean number of activities household members engage in with the child".

recode activity (4 thru hi = 1) (else = 0) into activ4.
variable label activ4 "Support for learning".

*------------------------------------------------------------------------------------------------------------------------- Birth registration.

compute regist = 0.
if (BR1 = 1 or BR2 = 1) regist = 1.
variable label regist "Birth registration".

*------------------------------------------------------------------------------------------------------------------------- Calculate sampling errors.

CSPLAN ANALYSIS
 /PLAN FILE='micsplan.csplan'
 /PLANVARS ANALYSISWEIGHT=chweight
 /DESIGN  STRATA= strat  CLUSTER= HH1
 /ESTIMATOR TYPE=WR.

* Complex Samples Descriptives.
CSDESCRIPTIVES
 /PLAN FILE = 'micsplan.csplan'
 /SUMMARY VARIABLES = wa2 bcg_r polio3_r dpt3_r meales_r all_r ari anti diarrhea orifcf activ4 regist
 /MEAN
 /STATISTICS SE CV COUNT POPSIZE DEFF DEFFSQRT
 /MISSING SCOPE = ANALYSIS CLASSMISSING = EXCLUDE.

new file.