*open the household listing data file.
get file = 'hl.sav'.

* create a variable that will reflect mother's line number.
compute mline = hl1

* create what will be mother's education level.
if ED3A = 6 OR ED3A = 8 OR ED3A = 9 melevel = 9.
if ED2 = 2 or ED3A = 0 melevel = 1.
if ED3A = 1 melevel = 2.
if ED3A = 2 and ED3B <= 9 melevel = 3.
if ED3A = 2 and ED3B >= 10 melevel = 4.
if ED3A = 3 melevel = 5.
if ED3A = 4 melevel = 6.

variable label melevel "Mother's education".
value label melevel
  1 "None"
  2 "Primary"
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "Non-standard/Missing/DK".

* For Uzbekistan:Collapsing education level "None" with "Primary" and "Non-standard/Missing/DK".
recode melevel (1,2 = 9).
value label melevel
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "None/Primary/Non-standard/Missing/DK".

* sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* save a mother's education file.
save outfile = 'tmpme.sav'
  /keep HH1 HH2 mline melevel.

* create a variable that will reflect father's line number.
compute fline = hl1

* create what will be father's education level.
if ED3A = 6 OR ED3A = 8 OR ED3A = 9 felevel = 9.
if ED2 = 2 or ED3A = 0 felevel = 1.
if ED3A = 1 felevel = 2.
if ED3A = 2 and ED3B <= 9 felevel = 3.
if ED3A = 2 and ED3B >= 10 felevel = 4.
if ED3A = 3 felevel = 5.
if ED3A = 4 felevel = 6.

variable label felevel "Father's education".
value label felevel
  1 "None"
  2 "Primary"
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "Non-standard/Missing/DK".

* For Uzbekistan:Collapsing education level "None" with "Primary" and "Non-standard/Missing/DK".
recode felevel (1,2 = 9).
value label felevel
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "None/Primary/Non-standard/Missing/DK".

* sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* save a father's education file.
save outfile = 'tmpfe.sav'
  /keep HH1 HH2 fline felevel.

* keep heads of household only.
select if (hl3 = 1).

* create head of household's education level.
if ED3A = 6 OR ED3A = 8 OR ED3A = 9 helevel = 9.
if ED2 = 2 or ED3A = 0 helevel = 1.
if ED3A = 1 helevel = 2.
if ED3A = 2 and ED3B <= 9 helevel = 3.
if ED3A = 2 and ED3B >= 10 helevel = 4.
if ED3A = 3 helevel = 5.
if ED3A = 4 helevel = 6.

variable label helevel "Education of household head".
value label helevel
  1 "None"
  2 "Primary"
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "Non-standard/Missing/DK".

* For Uzbekistan:Collapsing education level "None" with "Primary" and "Non-standard/Missing/DK".
recode helevel (1,2 = 9).
value label helevel
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "None/Primary/Non-standard/Missing/DK".

* sort the cases by cluster number, household number and head's line number.
sort cases by HH1 HH2 HL1.

* save a household head's education file.
save outfile = 'tmphhe.sav'
  /keep HH1 HH2 HL1 helevel.

* open the household listing data file.
get file = 'hl.sav'.

* compute mother's line number for household members aged 17 or younger.
if (HL7 <> 0) mline = HL7.
if (HL8 <> 0) mline = HL8.
if (hl5 < 18 and sysmis(mline)) mline = 0.
* use mother's line number if mother/caretaker from HL7 & HL8 is not available.
if (mline=0 and not sysmis(HL10) and HL10 <> 0) mline = HL10.
variable label mline "Mother's line number".

* sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* merge the mother's education file onto the household listing file.
match files
  /file = *
  /table = 'tmpme.sav'
  /by HH1 HH2 mline.

* recode mother's education level to deal with mothers who live elsewhere or are dead.
if (mline = 0) melevel = 5.

* compute father's line number for household members aged 17 or younger.
compute fline = HL12.
if (hl5 < 18 and sysmis(fline)) fline = 0.
variable label fline "Father's line number".

* sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* merge the father's education file onto the household listing file.
match files
  /file = *
  /table = 'tmpfe.sav'
  /by HH1 HH2 fline.

* recode father's education level to deal with fathers who live elsewhere or are dead.
if (fline = 0) felevel = 5.

* sort the cases by cluster number and household number.
sort cases by HH1 HH2.

* merge the household head file onto the household listing file.
match files
  /file = *
  /table = 'tmphhe.sav'
  /by HH1 HH2 .

* sort the cases by cluster number, household number and line number.
sort cases by HH1 HH2 HL1 .

* save the household listing data file.
save outfile = 'hl.sav'.

* erase the working files.
erase file = 'tmpme.sav'.
erase file = 'tmpfe.sav'.
erase file = 'tmphhe.sav'.
