* open the women file.
get file ="wm.sav".

* calculate the CMC date of interview.
compute cmcdoiw = (WM6Y - 1900)*12 + WM6M.
variable label cmcdoiw "Date of interview women (CMC)".

* set random number seed.
set seed = 1003.

* calculate the CMC date of birth and age.
do if (WM8Y < 9996 and WM8M < 96).
+ compute wdob = (WM8Y - 1900)*12 + WM8M.
else if (WM8Y < 9996).
+ compute aldob = cmcdoiw - WM9*12 - 11.
+ compute audob = cmcdoiw - WM9*12 - 0.
+ compute ldob = (WM8Y - 1900)*12 + 1.
+ compute udob = (WM8Y - 1900)*12 + 12.
+ if (ldob >= aldob & ldob <= audob) wdob = trunc(rv.uniform(ldob,audob)).
+ if (aldob >= ldob & aldob <= udob) wdob = trunc(rv.uniform(aldob,udob)).
+ if (ldob > audob | aldob > udob) wdob = trunc(rv.uniform(aldob,audob)).
else.
+ compute aldob = cmcdoiw - WM9*12 - 11.
+ compute audob = cmcdoiw - WM9*12 - 0.
+ compute wdob = trunc(rv.uniform(aldob,audob)).
end if.
if (cmcdoiw - wdob = 600) wdob = wdob + 1.
variable label wdob "Date of birth (CMC)".
missing values wdob (9999).

* calculate age in five year groups.
recode WM9 (15 thru 19 =1) (20 thru 24 = 2) (25 thru 29 =3) (30 thru 34 =4) 
	(35 thru 39 =5) (40 thru 44=6) (45 thru 49 =7) into wage.
variable label wage "Age".
value label wage
  1 "15-19"
  2 "20-24"
  3 "25-29"
  4 "30-34"
  5 "35-39"
  6 "40-44"
  7 "45-49".

* calculate age at first marriage.
do if (MA6Y < 9996 and MA6M < 96).
+ compute wdom = (MA6Y - 1900)*12 + MA6M.
+ compute agem = trunc ((wdom-wdob)/12) .
else if (MA8 < 96).
+ compute agem = MA8.
else if (not sysmis(MA6M)).
+ compute agem = 99.
end if.
variable label agem "Age at first marriage/union".
missing values agem (99).

* calculate marital status.
if (MA1 = 1 or MA1  = 2) mstatus = 1.
if (MA3 = 1 or MA3  = 2) mstatus = 2.
if (MA3 = 3) mstatus = 3.
variable label mstatus "Marital/Union status".
value label mstatus
  1 "Currently married/in union"
  2 "Formerly married/in union"
  3 "Never married/in union".

* calculate education level.
if WM7 = 1 melevel = 1.
if WM11 = 1 melevel = 2.
if WM11 = 2 and WM12 <= 9 melevel = 3.
if WM11 = 2 and WM12 >= 10 melevel = 4.
if WM11 = 3 melevel = 5.
if WM11 = 4 melevel = 6.
if WM11 = 6 OR WM11 = 8 OR WM11 = 9 melevel = 9.
variable label melevel "Woman's education level".
value label melevel
  1 "None"
  2 "Primary"
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "Non-standard/Missing/DK".

* For Uzbekistan:Collapsing education level "None" with "Primary" and "Non-standard/Missing/DK".
recode melevel (1,2 = 9).
value label melevel
  3 "Incomplete Secondary"
  4 "Complete Secondary"
  5 "Secondary special"
  6 "Higher education"
  9 "None/Primary/Non-standard/Missing/DK".

* calculate total children ever born.
compute ceb = 0.
if (CM1 = 1) ceb = CM9.
variable label ceb "Children ever born".

* calculate number of dead children.
compute deadkids = 0.
if (CM7 = 1) deadkids = CM8A + CM8B.
variable label deadkids "Dead children".

* reset variables for incomplete interviews.
do if (WM7 ~= 1).
+ recode wdob (lo thru hi=sysmis).
+ recode wage (lo thru hi=sysmis).
+ recode wdom (lo thru hi=sysmis).
+ recode agem (lo thru hi=sysmis).
+ recode mstatus (lo thru hi=sysmis).
+ recode melevel (lo thru hi=sysmis).
+ recode ceb (lo thru hi=sysmis).
+ recode deadkids (lo thru hi=sysmis).
end if.

*save the women's file.
save outfile = 'wm.sav'
   drop aldob audob ldob udob wdom.
